<?php
/** POSTCODES4u - Admin Page ********************************************************
 * Description: Postcodes4u Admin/Settings Page
 *  Updated 2019.07.04 - 'Trimmed' Key and Username
 *                          Added Header.
 *  Updated 2021.07.30 - Added 'Show Warnings' Flag and Customisable Button Text
 *                          Added Header.
 *  Updated 2022.06.29 - Added new 'No Aria' setting for Gravity Forms
 *                       Set 'Better Defaults' eg Use Smart Address Format
 *                        Tidyup of Gravity Settings on Admin Page
 *
 *  Updated 2023.01.05 - Removed 'No Aria' IAW Proper Code Fix.
 *                        Issue was caused by using Pre GravityForms 2.5
 *                       Small tweak to layout
 *
 * Version: 1.4
 * Author: Kevin Fisher - 3X Software
 * Plugin URI: plugins.3xsoftware.co.uk/wordpress-uk-address-finder
 *
 *************************************************************************************/

function pc4u_options_page() {

global $pc4u_options;

    ob_start(); ?>

    <div class="wrap">

        <h2>Postcodes4u Postcode Lookup Plugin Options</h2>

        <form method="post" action="options.php">

            <?php settings_fields('pc4u_settings_group');

            // Process Current/Default settings

            $currentSettings = get_option('pc4u_settings');

            $currentPc4uEnable = '0';

            $currentPc4uShowWarnings = '0';

            $currentPc4uUserName = '';

            $currentPc4uUserKey = '';

            $currentPc4uAddressDispFormat = '1';  // Default To 'Smart' Address Format - KRF 2022.06.27

            $currentPc4uAddressCountyFormat = '0';

            $currentPc4uTestForm = '0';

            $currentWoocommerce = '0';

            $currentWoocommercePosition = '0';

            $currentWooForceTemplateOverride = '0';

            $currentContactForm7 = '0';

            $currentGravityForm = '0';

            $currentGravityFormNoAutoIntegrate = '0';
            
            $currentGravityFormNoARIA = '0';
            
            // New Customisable Button Texts = KRF 2021.07.29 ---------------------------------------
            $currentPostcodeLookupButtonText = 'Lookup';
            $currentPostcodeAddressSelectDropdown = 'Select an Address:';
            $currentPostcodeManualEntryButtonText = 'Manual Address';

            if(isset($currentSettings['enable']) ) {
                $currentPc4uEnable = $currentSettings['enable'] ;
            }
            // Added 'Show Warnings - KRF 2021.07.20
             if(isset($currentSettings['show_warnings']) ) {
                $currentPc4uShowWarnings = $currentSettings['show_warnings'] ;
            }

            if(isset($currentSettings['user_name']) ) {
                $currentPc4uUserName = trim($currentSettings['user_name']) ;
            }

            if(isset($currentSettings['user_key']) ) {
                $currentPc4uUserKey = trim($currentSettings['user_key']) ;
            }


            // New Customisable Button Texts = KRF 2021.07.29 ---------------------------------------
            if(isset($currentSettings['lookup_button_text']) ) {
                $currentPostcodeLookupButtonText = trim($currentSettings['lookup_button_text']) ;
                if($currentPostcodeLookupButtonText == '') {
                    $currentPostcodeLookupButtonText = 'Lookup';
                }
            }
            
            if(isset($currentSettings['address_select_dropdown_text']) ) {
                $currentPostcodeAddressSelectDropdown = trim($currentSettings['address_select_dropdown_text']) ;
                if($currentPostcodeAddressSelectDropdown == '') {
                    $currentPostcodeAddressSelectDropdown = 'Select an Address:';
                }
            }
            
            if(isset($currentSettings['manual_address_button_text']) ) {
                $currentPostcodeManualEntryButtonText = trim($currentSettings['manual_address_button_text']) ;
                if($currentPostcodeManualEntryButtonText == '') {
                    $currentPostcodeManualEntryButtonText = 'Manual Address';
                }
            }
            // ----------------------------------------------------------------------
  
            
            // General Settings
            if(isset($currentSettings['alt_address_disp']) ) {
                // Only Allow If Postcode Integration Enabled
		if($currentPc4uEnable == '1') {
                    $currentPc4uAddressDispFormat = $currentSettings['alt_address_disp'] ;
		}
            }

            if(isset($currentSettings['county_address_disp']) ) {
                // Only Allow If Postcode Integration Enabled
		if($currentPc4uEnable == '1') {
                    $currentPc4uAddressCountyFormat = $currentSettings['county_address_disp'] ;
		}
            }

            if(isset($currentSettings['pc4u_testform']) ) {
		// Only Allow If Postcode Integration Enabled
		if($currentPc4uEnable == '1') {
                    $currentPc4uTestForm = $currentSettings['pc4u_testform'] ;
		}
            }

            // WooCommerce Settings
            if(isset($currentSettings['woointegrate']) ) {
                // Only Allow If Postcodes4u Integration Enabled
                if($currentPc4uEnable == '1') {
                    $currentWoocommerce = $currentSettings['woointegrate'] ;
                }
            }

            if(isset($currentSettings['woocommerce_position']) ) {
                // Only Allow If WooCommerce (And Pc4u) Integration Enabled
		if($currentWoocommerce == '1') {
                    $currentWoocommercePosition = $currentSettings['woocommerce_position'] ;
                }
            }

            if(isset($currentSettings['woocommerce_templateoverride']) ) {
                // Only Allow If WooCommerce (And Pc4u) Integration Enabled
                if($currentWoocommerce == '1') {
                    $currentWooForceTemplateOverride = $currentSettings['woocommerce_templateoverride'] ;
                }
            }

            // Contact Form 7 Integration
            if(isset($currentSettings['cf7integrate']) ) {
                // Only Allow If Postcodes4u Integration Enabled
                if($currentPc4uEnable == '1') {
                    $currentContactForm7 = $currentSettings['cf7integrate'] ;
                }
            }

            // Gravity Form Integration
            if(isset($currentSettings['gravityintegrate']) ) {
                // Only Allow If Postcodes4u Integration Enabled
                if($currentPc4uEnable == '1') {
                    $currentGravityForm = $currentSettings['gravityintegrate'] ;
                }
            }
            if(isset($currentSettings['gravityintegrate_noauto']) ) {
                // Only Allow If Postcodes4u Integration AND Gravity Forms Integration Enabled
                if($currentGravityForm == '1') {
                    $currentGravityFormNoAutoIntegrate = $currentSettings['gravityintegrate_noauto'] ;
                }
            }
            
              if(isset($currentSettings['gravityintegrate_noaria']) ) {
                // Only Allow If Postcodes4u Integration AND Gravity Forms Integration Enabled
                if($currentGravityForm == '1') {
                    $currentGravityFormNoARIA = $currentSettings['gravityintegrate_noaria'] ;
                }
            }


            ?>

            <h2>Enter your Postcodes4u key and Username to link to your Postcodes4u account.</h2>

            <h3>&nbsp;&nbsp;Login to your account at <a href="http://www.postcodes4u.co.uk"  target="_blank">Postcodes4u</a> for your account details.</h3>

            <h4><strong>&nbsp;&nbsp;<?php _e('Postcodes4u Key', 'pc4u_domain'); ?></strong>
                <br>
                <input id="pc4u_settings[user_key]" name="pc4u_settings[user_key]" type="text" class="regular-text" value="<?php echo trim($currentPc4uUserKey); ?>"/>
                <label class="description" for="pc4u_settings[user_key]"><?php _e('Enter your Postcodes4u Key', 'pc4u_domain'); ?></label>
            </h4>

            <h4><strong>&nbsp;&nbsp;<?php _e('Postcodes4u Username', 'pc4u_domain'); ?></strong>
                <br>
                <input id="pc4u_settings[user_name]" name="pc4u_settings[user_name]" type="text" class="regular-text" value="<?php echo trim($currentPc4uUserName); ?>"/>
                <label class="description" for="pc4u_settings[user_name]"><?php _e('Enter your Postcodes4u Username', 'pc4u_domain'); ?></label>
            </h4>
            <h3><?php _e('Postcodes4u Active', 'pc4u_domain'); ?></h3>
            <h3><strong>
                    This is the main Postcodes4u 'On/Off' switch.
                    <br/><br/>
                    <input id="pc4u_settings[enable]" name="pc4u_settings[enable]" type="checkbox" value="1" <?php checked('1',$currentPc4uEnable); ?> />
                    <label class="description" for="pc4u_settings[alt_address_disp]"><?php _e('Postcodes4u Postcode Lookups Enabled.', 'pc4u_domain'); ?></label>
            </h3></strong>
            </p>
            <p>&nbsp;</p>

            <h2>Postcodes4u General Settings.</h2>

            <p><strong><?php _e('PostCode Address Display Format', 'pc4u_domain'); ?></strong>
            <br>&nbsp;&nbsp;
            <input type="radio" name="pc4u_settings[alt_address_disp]" value="0"<?php checked( 0 == $currentPc4uAddressDispFormat ); ?> />
            <label class="description" for="pc4u_settings[alt_address_disp]"><?php _e('Use Raw Address format - duplicate fields may occur (eg Company Name).', 'pc4u_domain'); ?></label>
            <br>&nbsp;&nbsp;
            <input type="radio" name="pc4u_settings[alt_address_disp]" value="1"<?php checked( 1 == $currentPc4uAddressDispFormat ); ?> />
            <label class="description" for="pc4u_settings[alt_address_disp]"><?php _e("Use 'Smart' Address format (Recommended) - Makes best use of available address fields.", 'pc4u_domain'); ?></label>
            </p>

            <p><strong><?php _e('Postcode Lookup Address - County Display', 'pc4u_domain'); ?></strong>
            <br>&nbsp;&nbsp;
            <input type="radio" name="pc4u_settings[county_address_disp]" value="0"<?php checked( 0 == $currentPc4uAddressCountyFormat ); ?> />
            <label class="description" for="pc4u_settings[county_address_disp]"><?php _e('Use Default Address County. (Set on Postcodes4u Website For Key)', 'pc4u_domain'); ?></label>
            <br>&nbsp;&nbsp;
            <input type="radio" name="pc4u_settings[county_address_disp]" value="1"<?php checked( 1 == $currentPc4uAddressCountyFormat ); ?> />
            <label class="description" for="pc4u_settings[county_address_disp]"><?php _e('Use Administrative County Name.', 'pc4u_domain'); ?></label>
            <br>&nbsp;&nbsp;
            <input type="radio" name="pc4u_settings[county_address_disp]" value="2"<?php checked( 2 == $currentPc4uAddressCountyFormat ); ?> />
            <label class="description" for="pc4u_settings[county_address_disp]"><?php _e('Use Postal County Name.', 'pc4u_domain'); ?></label>
            <br>&nbsp;&nbsp;
            <input type="radio" name="pc4u_settings[county_address_disp]" value="3"<?php checked( 3 == $currentPc4uAddressCountyFormat ); ?> />
            <label class="description" for="pc4u_settings[county_address_disp]"><?php _e('Use Traditional County Name.', 'pc4u_domain'); ?></label>
            <br>&nbsp;&nbsp;
            <input type="radio" name="pc4u_settings[county_address_disp]" value="4"<?php checked( 4 == $currentPc4uAddressCountyFormat ); ?> />
            <label class="description" for="pc4u_settings[county_address_disp]"><?php _e('DO NOT DISPLAY COUNTY.', 'pc4u_domain'); ?></label>
            </p>

            <p><strong><?php _e('Enable Test LookUp Form', 'pc4u_domain'); ?></strong>
                <br>&nbsp;&nbsp;
                <input id="pc4u_settings[pc4u_testform]" name="pc4u_settings[pc4u_testform]" type="checkbox" value="1" <?php checked('1',$currentPc4uTestForm); ?> />
                <label class="description" for="pc4u_settings[pc4u_testform]"><?php _e('Enable the Test Postcodes4u Lookup Form', 'pc4u_domain'); ?></label>
            </p>
            <p><strong><?php _e('Show Postcode Lookup Warnings (eg. No Postcode Specified)', 'pc4u_domain'); ?></strong>
                <br>&nbsp;&nbsp;
                <input id="pc4u_settings[show_warnings]" name="pc4u_settings[show_warnings]" type="checkbox" value="1" <?php checked('1',$currentPc4uShowWarnings); ?> />
                <label class="description" for="pc4u_settings[show_warnings]"><?php _e('Enable Postcodes4u Lookup Warning Messages', 'pc4u_domain'); ?></label>
            </p>

            <p><strong>&nbsp;&nbsp;<?php _e('Postcodes4u Lookup Button Text', 'pc4u_domain'); ?></strong>
                <br>
                <input id="pc4u_settings[lookup_button_text]" name="pc4u_settings[lookup_button_text]" type="text" class="regular-text" value="<?php echo trim($currentPostcodeLookupButtonText); ?>"/>
                <label class="description" for="pc4u_settings[lookup_button_text]"><?php _e('Enter the Text For Your Postcode Lookup Buttons (Default is Lookup)', 'pc4u_domain'); ?></label>
            </p>
            <p><strong>&nbsp;&nbsp;<?php _e('Postcodes4u Address Selection Dropdown Text', 'pc4u_domain'); ?></strong>
                <br>
                <input id="pc4u_settings[address_select_dropdown_text]" name="pc4u_settings[address_select_dropdown_text]" type="text" class="regular-text" value="<?php echo trim($currentPostcodeAddressSelectDropdown); ?>"/>
                <label class="description" for="pc4u_settings[address_select_dropdown_text]"><?php _e('Enter the selection text for your Address Select Dropdown (Default is Select an Address:)', 'pc4u_domain'); ?></label>
            </p>
            <p>&nbsp;</p>

            <h2>Contact Form 7 Integration Settings.</h2>
            <p><strong><?php _e('Enable Contact Form 7 Integration', 'pc4u_domain'); ?></strong>
                <br>&nbsp;&nbsp;
                <input id="pc4u_settings[cf7integrate]" name="pc4u_settings[cf7integrate]" type="checkbox" value="1" <?php checked('1', $currentContactForm7); ?> />
                <label class="description" for="pc4u_settings[cf7integrate]"><?php _e('Show the Postcodes4u Lookup in Contact Form 7 (See Note).', 'pc4u_domain'); ?></label>
                <br/>&nbsp;<br/>
                <strong>Note.</strong>
                When using Contact Form 7 Integration the relevant address fields must be set up using the Postcodes4u ID Names.
                <br/>&nbsp;<br/>Full details of Integrating Postcodes4u with Contact Form7 can be found
                 <a href="http://www.postcodes4u.co.uk/support/Pc4u_CF7_SetupNotes.pdf"  target="_blank">HERE</a>.
                <br/>
            </p>
            <p>&nbsp;</p>

            <h2>Gravity Forms Integration Settings.</h2>
            <p><strong><?php _e('Enable Gravity Forms Integration', 'pc4u_domain'); ?></strong>
                <br>&nbsp;&nbsp;
                <input id="pc4u_settings[gravityintegrate]" name="pc4u_settings[gravityintegrate]" type="checkbox" value="1" <?php checked('1', $currentGravityForm); ?> />
                <label class="description" for="pc4u_settings[gravityintegrate]"><?php _e('Includes the Postcodes4u Address Field in Gravity Forms (See Note below).', 'pc4u_domain'); ?></label>     
                <br/>&nbsp;<br/>
                <strong>Note.</strong>
                This changes the normal Gravity Forms 'Address' advanced field to 'Pc4u Address'.  This updated field includes allows a postcode lookup to be added to a Gravity Form.
                <br/>
                The Options to display a Postcode Lookup, along with other display controls are displayed on the 'Appearance' tab of the Pc4u Address field
                <br/>
                <br>Full details of integrating Postcodes4u with GravityForms can be found
                <a href="http://www.postcodes4u.co.uk/support/Postcodes4u Gravity Form Setup.pdf"  target="_blank">HERE</a>.
                <br/>&nbsp;<br/>
               
                <strong><?php _e('   Disable Automatic Update of Gravity Forms for Postcodes4u', 'pc4u_domain'); ?></strong>
                <br/>&nbsp;&nbsp;
                <input name="pc4u_settings[gravityintegrate_noauto]" type="checkbox" value="1" <?php checked('1', $currentGravityFormNoAutoIntegrate); ?> />
                <label class="description" for="pc4u_settings[gravityintegrate_auto]"><?php _e('  If Checked <strong>DO NOT</strong> Automatically Update Gravity Forms file for Postcodes4u compatability (See Gravity Forms Update Information Note below)', 'pc4u_domain'); ?></label>
                <br/>&nbsp;<br/>&nbsp;&nbsp;
                
                <strong>Note:&nbsp;</strong> In order for the Postcodes4u integration to work a small change is required to a GravityForms file (gravityforms/includes/fields/class-gf-fields.php).
                <br/>&nbsp;&nbsp;
                This should not affect the normal operation of Gravity Forms.
                <br/>&nbsp;<br/>&nbsp;&nbsp;
                If the <strong>'Disable Automatic Update of Gravity Forms for Postcodes4u'</strong> is not checked, and Gravity Forms integration is enabled, (Enable Gravity Forms Integration is checked),
                <br>&nbsp;&nbsp;
                the Postcodes4u plugin will automatically update the GravityForms file whenever required.  This will be when the Gravity Forms options are initially selected, and whenever a GravityForms update changes the file.
                <br/>
                <br>&nbsp;&nbsp;
                <strong>If you wish to use Postcodes4u postcode lookup in GravityForms but do not want to use the automatic update option then check this 'Disable Automatic Update' option.</strong>
                 <br>&nbsp;&nbsp;&nbsp;You will then need to edit the GravityForms file (gravityforms/includes/fields/class-gf-fields.php) manually using the WordPress Source editor.
                 <br>&nbsp;&nbsp;&nbsp;Full details of the what is required can be found in the GravityForms Integration Guide which can be found
                <a href="http://www.postcodes4u.co.uk/support/Postcodes4u Gravity Form Setup.pdf"  target="_blank">HERE</a>.
                <br/>&nbsp;<br/>&nbsp;<br/>
                
                <strong><?php _e('Postcodes4u Manual Address Selection Button Text', 'pc4u_domain'); ?></strong>
                    <br>
                    <input id="pc4u_settings[manual_address_button_text]" name="pc4u_settings[manual_address_button_text]" type="text" class="regular-text" value="<?php echo trim($currentPostcodeManualEntryButtonText); ?>"/>
                    <label class="description" for="pc4u_settings[manual_address_button_text]"><?php _e('Enter the Text For Your Manual Address Entry Button (Default Manual Address) For Gravity Forms.', 'pc4u_domain'); ?></label>
              
                <br/>&nbsp;<br/>
                                              
<!--                <strong>Disable Gravity Forms 'ARIA' display enhancements.</strong>
                <br>&nbsp;&nbsp;
                <input name="pc4u_settings[gravityintegrate_noaria]" type="checkbox" value="1" <?php checked('1', $currentGravityFormNoARIA); ?> />
                <label class="description" for="pc4u_settings[gravityintegrate_aria"><?php _e('  <strong>ONLY CHECK this if you are seeing ARIA Processing Errors in your Postcodes4u GravityForms as it is likely to display incorrect data on the GravityForm edit page.</strong>', 'pc4u_domain'); ?></label>
                <br/>&nbsp;<br/>-->
            </p>
            <p>&nbsp;</p>


            <h2>WooCommerce Integration Settings.</h2>
            <p><strong><?php _e('Enable Postcodes4u Integration in WooCommerce Checkout', 'pc4u_domain'); ?></strong>
                <br>&nbsp;&nbsp;
                <input id="pc4u_settings[woointegrate]" name="pc4u_settings[woointegrate]" type="checkbox" value="1" <?php checked('1', $currentWoocommerce); ?> />
                <label class="description" for="pc4u_settings[woointegrate]"><?php _e('Show the Postcodes4u Lookup in WooCommerce Checkout', 'pc4u_domain'); ?></label>
            </p>
            <p><strong><?php _e('   WooCommerce Postcode Lookup Display Position', 'pc4u_domain'); ?></strong>
                <br>&nbsp;&nbsp;
                <input name="pc4u_settings[woocommerce_position]" type="radio" value="0" <?php checked('0', $currentWoocommercePosition); ?> />
                <label class="description" for="pc4u_settings[woocommerce_position]"><?php _e('  At Top of Billing/Shipping Address (Default)', 'pc4u_domain'); ?></label>
                <br>&nbsp;&nbsp;
                <input name="pc4u_settings[woocommerce_position]" type="radio" value="1" <?php checked('1', $currentWoocommercePosition); ?> />
                <label class="description" for="pc4u_settings[woocommerce_position]"><?php _e('  Before Company Name', 'pc4u_domain'); ?></label>
                <br>&nbsp;&nbsp;
                <input name="pc4u_settings[woocommerce_position]" type="radio" value="2" <?php checked('2', $currentWoocommercePosition); ?> />
                <label class="description" for="pc4u_settings[woocommerce_position]"><?php _e('  Before First Line Of Address', 'pc4u_domain'); ?></label>
                <br>&nbsp;&nbsp;
                <input name="pc4u_settings[woocommerce_position]" type="radio" value="3" <?php checked('3', $currentWoocommercePosition); ?> />
                <label class="description" for="pc4u_settings[woocommerce_position]"><?php _e('  After First Line Of Address', 'pc4u_domain'); ?></label>
                <br>&nbsp;&nbsp;
                <input name="pc4u_settings[woocommerce_position]" type="radio" value="4" <?php checked('4', $currentWoocommercePosition); ?> />
                <label class="description" for="pc4u_settings[woocommerce_position]"><?php _e('  After Town/City Line Of Address', 'pc4u_domain'); ?></label>
            </p>
            <p><strong><?php _e('Override Child Theme WooCommerce Checkout Templates', 'pc4u_domain'); ?></strong>
                <br>&nbsp;&nbsp;
                <input id="pc4u_settings[woocommerce_templateoverride]" name="pc4u_settings[woocommerce_templateoverride]" type="checkbox" value="1" <?php checked('1', $currentWooForceTemplateOverride); ?> />
                <label class="description" for="pc4u_settings[woocommerce_templateoverride]"><?php _e('Override Theme WooCommerce Checkout Templates. (See Note.)', 'pc4u_domain'); ?></label>
                <br><br>
                <strong>Note.</strong>
                Use this option if the current WordPress theme has it's own WooCommerce address templates, and you wish to use Postcode Lookup on the Billing and Shipping address pages.
                <br>
                &nbsp;&nbsp;Be aware that this may affect the styling of the Woocommerce address pages.
                <br>
            </p>
            <p class="submit">
                <input type="submit" class="button-primary" value="<?php _e('Save Options', 'pc4u_domain'); ?>" />
            </p>

        </form>

    </div>

    <?php

    echo ob_get_clean();

}



function pc4u_validate_settings( $pc4uInput ) {

    // If No User Details Then mark Postcodes4u as not enabled

    if( trim($pc4uInput['user_name']) === '' || trim($pc4uInput['user_key'] === '')) {

        // NO User Details - DISABLE POSTCODES 4u

         $pc4uInput['enable'] = '0';

         $pc4uInput['woointegrate'] = '0';

         $pc4uInput['cf7integrate'] = '0';

         $pc4uInput['gravityintegrate'] = '0';

         add_settings_error( 'pc4u_settings',  esc_attr( 'settings_updated' ),
            'You cannot enable the Postcodes4u Postcode Lookup without entering a Username and Key', 'pc4u_domain' );

    }

    return $pc4uInput;

}



function pc4u_add_options_link() {

    add_options_page('PC4U Plugin Options', 'Postcodes4U', 'manage_options', 'pc4u-options', 'pc4u_options_page');

}

add_action('admin_menu', 'pc4u_add_options_link');



function pc4u_register_settings() {

    register_setting('pc4u_settings_group', 'pc4u_settings', 'pc4u_validate_settings');
}

add_action('admin_init', 'pc4u_register_settings');



