<?php
/** POSTCODES4u - WooCommerce Integration *************************************************
 * Description: Updates Postcode Field In Checkout Billing and Shipping Address
 *
 *  Updated 2019.03.01 - Added to update address priority post WooCommerce 2.4.3
 *  Updated 2020.11.16 - Moved WooCommerce Default Checkout Address Code from main file
 *                         Updated for new Filters
 *
 *  Updated 2021.03.22 - Updated Postcode Field Width Processing (Use form-row-first)
 *
 *
 * Version: 1.2  Dated 24/03/2021
 * Author: Kevin Fisher - 3X Software
 * Plugin URI: plugins.3xsoftware.co.uk/wordpress-uk-address-finder
 ******************************************************************************************/

// Locate Postodes4u Checkout Templates
add_filter( 'woocommerce_locate_template', 'pc4uplugin_woocommerce_locate_template', 10, 3 );

// Set Default Checkout Billing & Shipping Country to UK

add_filter( 'default_checkout_billing_country', 'change_default_checkout_country',10, 1 );
add_filter( 'default_checkout_shipping_country', 'change_default_checkout_country',10, 1 );


//  Update Postcode Field Priority Based on Position Settings
add_filter( 'woocommerce_default_address_fields' , 'postcodes4u_woocommerce_checkout_fields', 9999 );


// Locate Poctodes4u Checkout Templates
function pc4uplugin_woocommerce_locate_template( $template, $template_name, $template_path ) {

  global $woocommerce;
  global $pc4u_options;

  $_template = $template;

  if ( ! $template_path ) $template_path = $woocommerce->template_url;

  $plugin_path  = pc4uplugin_plugin_path() . '/woocommerce/';


  // Check For WooCommerce Pc4u Integration Active && Template Override
  if(isset($pc4u_options['woointegrate']) &&
        (($pc4u_options['woointegrate'] == true || $pc4u_options['woointegrate'] == '1')) &&
      (isset($pc4u_options['woocommerce_templateoverride']) &&
        ($pc4u_options['woocommerce_templateoverride'] == true || $pc4u_options['woocommerce_templateoverride'] == '1'))) {

        // CHECK PLUGIN THEN THEME - NOT NORMAL BEHAVIOUR
        // Get the template from Postcodes 4u plugin, if it exists
        if (file_exists( $plugin_path . $template_name )) {
            $template = $plugin_path . $template_name;
        }

        if (! $template) {
            // Look within passed path within the theme - this is priority
            $template = locate_template(
            array(  $template_path . $template_name, $template_name ));
        }
  } else {
  		// Default Behavior - Theme Then Plugin
  		// Look within passed path within the theme - this is priority
  		$template = locate_template(
    		array(  $template_path . $template_name, $template_name ));

  		// Get the template from Postcodes 4u plugin, if it exists
    	if (!$template && file_exists( $plugin_path . $template_name )) {
	        $template = $plugin_path . $template_name;
	    }
  }


  // Use default template if Theme/Plugin not set
  if ( ! $template )
    $template = $_template;


  // Return what we found
  return $template;

}


// Set Default Checkout Billing & Shipping Country to UK
//
// Set United Kingdom (GB)
function change_default_checkout_country($countrycode) {
    global $pc4u_options;
    if(isset($pc4u_options['woointegrate']) &&
        (($pc4u_options['woointegrate'] == true || $pc4u_options['woointegrate'] == '1'))){
        $countrycode = "GB";
    }

    return $countrycode;
}


//  Update Postcode Field Priority Based on Position Settings

// postcodes4u_woocommerce_checkout_fields
// ---------------------------------------
//  Update Postcode Field Priority Based on Position Settings
//
function postcodes4u_woocommerce_checkout_fields( $fields ) {
    global $pc4u_options;
    // Check If Woo Commerce Postcodes4u Address lookup required
    if (isset($pc4u_options) && isset($pc4u_options['woointegrate']) &&
      ($pc4u_options['woointegrate'] == true || $pc4u_options['woointegrate'] == '1')) {
    	// Custom Billing Form Processing for Postcodes4u Lookup
    	$pc4uDisplayed="no";

    	// Set Postcodes4u Lookup Form Location
    	//    New Position IDs 10-1st Name, 20-Last Name, 30-Company,
    	//      40-Country, 50-Street1,60-Street 2(appt), 70-TownCity, 80-CountyState, 90-Postcode
    	$pc4uPosition="top";
    	$pc4uPositionPriority=4;
      	if(isset($pc4u_options['woocommerce_position'])){
        	if($pc4u_options['woocommerce_position'] == '1' ) {
            	$pc4uPositionPriority=24;
           	} else {
            	if($pc4u_options['woocommerce_position'] == '2') {
                	$pc4uPositionPriority=44;
               	} else {
                	if($pc4u_options['woocommerce_position'] == '3') {
                   		$pc4uPositionPriority=54;
                   	} else {
                    	if($pc4u_options['woocommerce_position'] == '4') {
              		        $pc4uPositionPriority=74;
                  	    }
                  	}
              	}
         	}
            }
            $fields['postcode']['priority']=$pc4uPositionPriority;

            // Force Half Form Width for Postcodes4u Postcode field
            $fields['postcode']['class'] = array('form-row-first');
  	}
    return $fields;
}


?>